@@ -1,13 +1,16 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.23';
+$App::pherkin::VERSION = '0.24';
 use strict;
 use warnings;
 
 use FindBin::libs;
 use Getopt::Long;
-use Test::BDD::Cucumber::I18n qw(languages langdef readable_keywords keyword_to_subname);
+use Module::Runtime qw(use_module);
 use List::Util qw(max);
 
+use Test::BDD::Cucumber::I18n qw(languages langdef readable_keywords keyword_to_subname);
+use Test::BDD::Cucumber::Loader;
+
 use Moose;
 has 'tags' => ( is => 'rw', isa => 'ArrayRef', required => 0 );
 has 'tag_scheme' => ( is => 'rw', isa => 'ArrayRef', required => 0 );
@@ -18,7 +21,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -36,10 +39,6 @@ Steps that pass will be printed in green, those that fail in red, and those
 for which there is no step definition as yellow (for TODO), assuming you're
 using the default output harness.
 
-=cut
-
-use Test::BDD::Cucumber::Loader;
-
 =head1 METHODS
 
 =head2 run
@@ -65,9 +64,7 @@ sub run {
     );
     die "No feature files found" unless @features;
 
-    eval "require $options->{'harness'}" || die $@;
-    my $harness  = $options->{'harness'}->new();
-    $harness->startup();
+    my $harness = $self->_load_harness( $options->{'harness'} );
 
     my $tag_spec;
     if ($self->tag_scheme) {
@@ -80,6 +77,22 @@ sub run {
     return $harness->result;
 }
 
+sub _load_harness {
+    my ( $self, $harness_module ) = @_;
+
+    unless ( $harness_module =~ m/::/ ) {
+        $harness_module = "Test::BDD::Cucumber::Harness::" . $harness_module;
+    }
+
+    eval { use_module( $harness_module ) } ||
+        die "Unable to load harness [$harness_module]: $@";
+
+    my $harness = $harness_module->new();
+    $harness->startup();
+
+    return $harness;
+}
+
 sub _process_arguments {
     my ( $self, @args ) = @_;
     local @ARGV = @args;
@@ -108,8 +121,6 @@ sub _process_arguments {
 
     # Munge the output harness
     $harness //= "TermColor";
-    $harness = "Test::BDD::Cucumber::Harness::$harness" unless
-        $harness =~ m/\:\:/;
 
     lib->import(@$includes) if @$includes;
 
