@@ -1,12 +1,14 @@
 package Test::BDD::Cucumber::I18n;
-$Test::BDD::Cucumber::I18n::VERSION = '0.23';
+$Test::BDD::Cucumber::I18n::VERSION = '0.24';
+=encoding utf8
+
 =head1 NAME
 
 Test::BDD::Cucumber::I18N - Internationalization
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 DESCRIPTION
 
@@ -58,15 +60,37 @@ sub _initialize_language_definitions_from_shared_json_file {
     return $langdefs;
 }
 
+=head1 METHODS
+
+=head2 languages
+
+Get codes of supported languages.
+
+=cut
+
 sub languages {
     return keys %$langdefs;
 }
 
+=head2 has_language($language)
+
+Check if a language is supported.  Takes as argument the language
+abbreviation defined in C<share/i18n.json>.
+
+=cut
+
 sub has_language {
     my ($language) = @_;
     exists $langdefs->{$language};
 }
 
+=head2 langdef($language)
+
+Get definition of a language.  Takes as argument the language abbreviation
+defined in C<share/i18n.json>.
+
+=cut
+
 sub langdef {
     my ($language) = @_;
 
@@ -74,6 +98,12 @@ sub langdef {
     return $langdefs->{$language};
 }
 
+=head2 readable_keywords($string, $transform)
+
+Get readable keyword definitions.
+
+=cut
+
 sub readable_keywords {
     my ( $string, $transform ) = @_;
 
@@ -84,6 +114,12 @@ sub readable_keywords {
     return join( ', ', map { '"' . $_ . '"' } @keywords );
 }
 
+=head2 keyword_to_subname
+
+Return a keyword into a subname with non-word characters removed.
+
+=cut
+
 sub keyword_to_subname {
     my ($word) = @_;
 
