@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.23';
+$Test::BDD::Cucumber::Parser::VERSION = '0.24';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 DESCRIPTION
 
@@ -32,7 +32,6 @@ L<Test::BDD::Cucumber::Model::Feature> object on success.
 use strict;
 use warnings;
 
-use Ouch;
 use File::Slurp;
 
 use Test::BDD::Cucumber::Model::Document;
@@ -41,10 +40,13 @@ use Test::BDD::Cucumber::Model::Scenario;
 use Test::BDD::Cucumber::Model::Step;
 use Test::BDD::Cucumber::Model::TagSpec;
 use Test::BDD::Cucumber::I18n qw(langdef);
+use Test::BDD::Cucumber::Errors qw/parse_error_from_line/;
 
 # https://github.com/cucumber/cucumber/wiki/Multiline-Step-Arguments
 # https://github.com/cucumber/cucumber/wiki/Scenario-outlines
 
+
+
 sub parse_string {
 	my ( $class, $string, $tag_scheme ) = @_;
 
@@ -63,13 +65,13 @@ sub parse_file   {
 
 sub _construct {
 	my ( $class, $document, $tag_scheme ) = @_;
-	
+
 	my $feature = Test::BDD::Cucumber::Model::Feature->new({ document => $document });
         my @lines = $class->_remove_next_blanks( @{ $document->lines } );
 
 	$feature->language($class->_extract_language(\@lines));
 
-	my $self = { langdef => 
+	my $self = { langdef =>
 		     langdef($feature->language) };
         bless $self, $class;
 
@@ -124,7 +126,7 @@ sub _extract_feature_name {
 			push( @feature_tags, @tags );
 
 		} else {
-			ouch 'parse_error', "Malformed feature line", $line;
+			die parse_error_from_line( "Malformed feature line", $line );
 		}
 	}
 
@@ -163,8 +165,8 @@ sub _extract_scenarios {
 
             # Only one background section, and it must be the first
             if ( $scenarios++ && $type =~ m/^($langdef->{background})/ ) {
-                ouch 'parse_error', "Background not allowed after scenarios",
-                  $line;
+                die parse_error_from_line( "Background not allowed after scenarios",
+                  $line);
             }
 
             # Create the scenario
@@ -193,7 +195,7 @@ sub _extract_scenarios {
             push( @scenario_tags, @tags );
 
         } else {
-            ouch 'parse_error', "Malformed scenario line", $line;
+            die parse_error_from_line( "Malformed scenario line", $line );
         }
     }
 
@@ -245,8 +247,7 @@ m/^((?:$langdef->{given})|(?:$langdef->{and})|(?:$langdef->{when})|(?:$langdef->
             return $self->_extract_table( 6, $scenario,
                 $self->_remove_next_blanks(@lines) );
         } else {
-            warn $line->content;
-            ouch 'parse_error', "Malformed step line", $line;
+            die parse_error_from_line( "Malformed step line", $line );
         }
     }
 
@@ -313,7 +314,7 @@ sub _extract_table {
 		}
 
 		if ( @columns ) {
-			ouch 'parse_error', "Inconsistent number of rows in table", $line
+			die parse_error_from_line( "Inconsistent number of rows in table", $line )
 				unless @rows == @columns;
             $target->columns( [ @columns ] ) if $target->can('columns');
 			my $i = 0;
@@ -336,12 +337,6 @@ sub _pipe_array {
 
 1;
 
-=head1 ERROR HANDLING
-
-L<Test::BDD::Cucumber> uses L<Ouch> for exception handling. Errors originating in this
-class tend to have a code of C<parse_error> and a L<Test::BDD::Cucumber::Model::Line>
-object for data.
-
 =head1 AUTHOR
 
 Peter Sergeant C<pete@clueball.com>
